import typer
import json

from pathlib import Path
from typing import Optional

from .converter import convert as convert_json

app = typer.Typer()


def checK_input(input: Path):
    """
    Check if the input file is a valid input
    """
    if not input.exists():
        raise typer.Abort('File does not exist')

    if not input.is_file():
        raise typer.Abort('It is not a file')

    if not input.suffix == '.json':
        raise typer.Abort('It is not a json file')


def check_output(path: Path):
    """
    Check is the output path is a valid dir
    """
    if not path.is_dir():
        raise typer.Abort()


@app.command()
def convert(
    input_file: Path,
    output_path: Optional[Path] = typer.Option(Path('.')),
):
    """
    Convert the JSON file into a CSV
    """

    checK_input(input_file)
    check_output(output_path)

    filename = input_file.stem
    filename = f'{filename}-converted.csv'

    output_file = output_path.joinpath(filename)
    output_file.touch(exist_ok=True)

    try:
        convert_json(input_file, output_file)
    except Exception as e:
        raise typer.Abort()



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['json_to_csv_lol']

package_data = \
{'': ['*']}

install_requires = \
['polars>=0.16.16,<0.17.0', 'typer[all]>=0.7.0,<0.8.0']

entry_points = \
{'console_scripts': ['json-to-csv-lol = json_to_csv-lol.main:app']}

setup_kwargs = {
    'name': 'json-to-csv-lol',
    'version': '0.1.1',
    'description': '',
    'long_description': '# JSON to CSV Converter\n\nThis is a simple package for convert a JSON to a CSV File',
    'author': 'Eduardo Alvarez',
    'author_email': 'walojose46@gmail.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/walis85300/json-to-csv-lol.git',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.10,<4.0',
}


setup(**setup_kwargs)
